#!/bin/bash

Help()
{
  echo "🗒  Setup everything needed for satisfactory to work on a Sylius plugin project."
  echo
  echo "Syntax: setup [-f|h|t]"
  echo "options:"
  echo "f     Force (useful, when it has already been setup)."
  echo "h     Print this Help."
  echo "i     Append .gitignore with files and directories created by this script."
  echo "t     Print tips."
  echo
}

Tips()
{
  echo "🗒  You might want to add the following to your .gitignore"
  echo
  echo "###> dedi ###"
  echo ".idea"
  echo ".gitmodules"
  echo "satisfactory"
  echo "Makefile"
  echo "docker-compose.yml"
  echo "$0 # this script"
  echo "###< dedi ###"
  echo
}

# Main Program
force=0
appendGitignore=0
while getopts ":fhit" option; do
  case $option in
    f) # force
      force=1
      break;;
    h) # display Help
      Help
      exit;;
    i) # append .gitignore
      appendGitignore=1
      break;;
    t) # display Tips
      Tips
      exit;;
    \?) # incorrect option
      echo "Error: Invalid option"
      exit;;
  esac
done

# Check if satisfactory is not setup yet
if [[ $force -eq 0 && -d satisfactory ]]; then
  echo "It seems satisfactory has already been setup"
  echo "Please use this script with the -f option"
  echo
  echo "For help, use"
  echo "$ bash $0 -h"
  echo

  exit 1;
fi

echo "🧽 Cleaning previous install"
git submodule deinit -f satisfactory
rm -rf .git/modules/satisfactory satisfactory
rm -f .gitmodules Makefile docker-compose.yml tests/Application/.env.local
touch .gitmodules

echo "🏗  Add satisfactory submodule"
git submodule add -f git@gitlab.com:dedi-agency/interne/satisfactory.git satisfactory
git submodule update --init --recursive satisfactory
# let's make sure satisfactory and .gitmodules are not commited
git restore --staged satisfactory .gitmodules

echo "🏗  Create Makefile"
echo "include satisfactory/sylius-plugin/Makefile" > Makefile

echo "🏗  Create docker-compose.yml"
echo "version: '3.4'" > docker-compose.yml

echo "🏗  Create tests/Application/.env.local"
echo "DATABASE_URL=mysql://root@mysql/sylius_plugin_%kernel.environment%?serverVersion=5.5" > tests/Application/.env.local

echo "💪  Done"

echo "🔧 Start, setup your database & build assets"
echo "$ make restart"
echo "$ make db-drop && make db-create && make db-update && make fixtures"
echo "$ make build"

if [[ $appendGitignore -eq 0 ]]; then
  echo "🔧 Appending .gitignore with all the files and directories created by this script."

  echo >> .gitignore
  echo "###> dedi ###" >> .gitignore
  echo ".idea" >> .gitignore
  echo ".gitmodules" >> .gitignore
  echo "satisfactory" >> .gitignore
  echo "Makefile" >> .gitignore
  echo "docker-compose.yml" >> .gitignore
  echo $0 >> .gitignore
  echo "###< dedi ###" >> .gitignore
fi
